# amenityPj

Source code of [https://amenitypj.in/](https://amenitypj.in/)
<BR>Amenity Pj is a collection of FREE & Open Source Apps including asn1Play, tlvPlay, qrPlay, excelPlay, certPlay.

# Stats

[![GitHub License](https://img.shields.io/github/license/impratikjaiswal/amenitypj)](LICENSE)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)

[![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/amenitypj)](https://github.com/impratikjaiswal/amenitypj/releases/latest)
[![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/amenitypj/latest)](https://github.com/impratikjaiswal/amenitypj/commits/main/)

[![Static Badge](https://img.shields.io/badge/amenitypj.in-a?label=website%20url)](https://amenitypj.in/)
[![Website](https://img.shields.io/website?url=https://amenitypj.in&label=website%20status)](https://amenitypj.in/)

[![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/)
[![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io&label=website%20status)](https://impratikjaiswal.github.io/)

# Url(s) of AmenityPj 

## Primary Url(s) of AmenityPj 
1. <a href="https://amenitypj.in/">https://amenitypj.in</a> [![Static Badge](https://img.shields.io/badge/amenitypj.in-a?label=primary%20url)](https://amenitypj.in/)
[![Website](https://img.shields.io/website?url=https://amenitypj.in&label=website%20status)](https://amenitypj.in/)

## Secondary Url(s) of AmenityPj 
If Primary Url(s) did not work for you (or its down), try these:
1. <a href="https://ec2-3-149-113-14.us-east-2.compute.amazonaws.com">https://ec2-3-149-113-14.us-east-2.compute.amazonaws.com</a>
1. <a href="https://3.149.113.14">https://3.149.113.14</a>
1. <a href="http://amenitypj.in/">http://amenitypj.in</a>

# Screen Shot(s) of Web App [![Static Badge](https://img.shields.io/badge/amenitypj.in-a)](https://amenitypj.in/) 
![sample_web_1](https://github.com/impratikjaiswal/amenitypj/blob/main/amenity_pj/static/images/samples/sample_web_1.gif?raw=true)

# Installation/Setup

Steps can be found [here](https://github.com/impratikjaiswal/pythonHelpers/blob/main/HOW_TO_INSTALL_PYTHON_APPS.md).

# How To Use

There are various ways to Get Started:

- Online Mode
   - Website [![Static Badge](https://img.shields.io/badge/amenitypj.in-a)](https://amenitypj.in/) can be used
- Offline Mode (Requires Download / Cloning of the Repo)
  - Code can be directly run from ```amenitypj/amenity_pj/app.py``` using any IDE
  - Local Web server can be started by running ```/scripts/server_amenity_pj_start_debug.bat```

# Help

Issue tracker can be found [here](CONTRIBUTING.md#issue-tracker).

# Contributing

- Code of Conduct can be found [here](CODE_OF_CONDUCT.md).
- Contributing Guidelines can be found [here](CONTRIBUTING.md).

# References &amp; Statistics

1. [Amenity Pj](https://impratikjaiswal.github.io/amenitypj)

    ![GitHub License](https://img.shields.io/github/license/impratikjaiswal/amenitypj)

    [![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/amenitypj)](https://github.com/impratikjaiswal/amenitypj/releases/latest)
    [![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/amenitypj/latest)](https://github.com/impratikjaiswal/amenitypj/commits/main/)
    
    [![Static Badge](https://img.shields.io/badge/amenitypj.in-a?label=website%20url)](https://amenitypj.in)
    [![Website](https://img.shields.io/website?url=https://amenitypj.in&label=website%20status)](https://amenitypj.in)
    
    [![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/)
    [![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io&label=website%20status)](https://impratikjaiswal.github.io/)

2. [ASN1 Play](https://impratikjaiswal.github.io/asn1Play/)

    ![GitHub License](https://img.shields.io/github/license/impratikjaiswal/asn1Play)

    [![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/asn1Play)](https://github.com/impratikjaiswal/asn1Play/releases/latest)
    [![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/asn1Play/latest)](https://github.com/impratikjaiswal/asn1Play/commits/main/)
    
    [![Static Badge](https://img.shields.io/badge/amenitypj.in/asn1Play-a?label=website%20url)](https://amenitypj.in/asn1Play)
    [![Website](https://img.shields.io/website?url=https://amenitypj.in/asn1Play&label=website%20status)](https://amenitypj.in/asn1Play)
    
    [![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io/asn1Play-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/asn1Play)
    [![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io/asn1Play&label=website%20status)](https://impratikjaiswal.github.io/asn1Play)

3. [TLV Play](https://impratikjaiswal.github.io/tlvPlay/)

    ![GitHub License](https://img.shields.io/github/license/impratikjaiswal/tlvPlay)

    [![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/tlvPlay)](https://github.com/impratikjaiswal/tlvPlay/releases/latest)
    [![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/tlvPlay/latest)](https://github.com/impratikjaiswal/tlvPlay/commits/main/)
    
    [![Static Badge](https://img.shields.io/badge/amenitypj.in/tlvPlay-a?label=website%20url)](https://amenitypj.in/tlvPlay)
    [![Website](https://img.shields.io/website?url=https://amenitypj.in/tlvPlay&label=website%20status)](https://amenitypj.in/tlvPlay)

    [![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io/tlvPlay-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/tlvPlay)
    [![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io/tlvPlay&label=website%20status)](https://impratikjaiswal.github.io/tlvPlay)

4. [QR Play](https://impratikjaiswal.github.io/qrPlay/)

    ![GitHub License](https://img.shields.io/github/license/impratikjaiswal/qrPlay)    

    [![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/qrPlay)](https://github.com/impratikjaiswal/qrPlay/releases/latest)
    [![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/qrPlay/latest)](https://github.com/impratikjaiswal/qrPlay/commits/main/)
    
    [![Static Badge](https://img.shields.io/badge/amenitypj.in/qrPlay-a?label=website%20url)](https://amenitypj.in/qrPlay)
    [![Website](https://img.shields.io/website?url=https://amenitypj.in/qrPlay&label=website%20status)](https://amenitypj.in/qrPlay)
    
    [![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io/qrPlay-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/qrPlay)
    [![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io/qrPlay&label=website%20status)](https://impratikjaiswal.github.io/qrPlay)

5. [Excel Play](https://impratikjaiswal.github.io/excelPlay/)

    ![GitHub License](https://img.shields.io/github/license/impratikjaiswal/excelPlay)

    [![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/excelPlay)](https://github.com/impratikjaiswal/excelPlay/releases/latest)
    [![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/excelPlay/latest)](https://github.com/impratikjaiswal/excelPlay/commits/main/)
    
    [![Static Badge](https://img.shields.io/badge/amenitypj.in/excelPlay-a?label=website%20url)](https://amenitypj.in/excelPlay)
    [![Website](https://img.shields.io/website?url=https://amenitypj.in/excelPlay&label=website%20status)](https://amenitypj.in/excelPlay)
    
    [![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io/excelPlay-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/excelPlay)
    [![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io/excelPlay&label=website%20status)](https://impratikjaiswal.github.io/excelPlay)

6. [Cert Play](https://impratikjaiswal.github.io/certPlay/)

    ![GitHub License](https://img.shields.io/github/license/impratikjaiswal/certPlay)

    [![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/certPlay)](https://github.com/impratikjaiswal/certPlay/releases/latest)
    [![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/certPlay/latest)](https://github.com/impratikjaiswal/certPlay/commits/main/)
    
    [![Static Badge](https://img.shields.io/badge/amenitypj.in/certPlay-a?label=website%20url)](https://amenitypj.in/certPlay)
    [![Website](https://img.shields.io/website?url=https://amenitypj.in/certPlay&label=website%20status)](https://amenitypj.in/certPlay)
    
    [![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io/certPlay-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/certPlay)
    [![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io/certPlay&label=website%20status)](https://impratikjaiswal.github.io/certPlay)

7. [Python Helpers](https://impratikjaiswal.github.io/pythonHelpers/)

    ![GitHub License](https://img.shields.io/github/license/impratikjaiswal/pythonHelpers)

    [![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/pythonHelpers)](https://github.com/impratikjaiswal/pythonHelpers/releases/latest)
    [![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/pythonHelpers/latest)](https://github.com/impratikjaiswal/pythonHelpers/commits/main/)
    
    [![Static Badge](https://img.shields.io/badge/amenitypj.in/-a?label=website%20url)](https://amenitypj.in)
    [![Website](https://img.shields.io/website?url=https://amenitypj.in&label=website%20status)](https://amenitypj.in)
    
    [![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io/pythonHelpers-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/pythonHelpers)
    [![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io/pythonHelpers&label=website%20status)](https://impratikjaiswal.github.io/pythonHelpers)
